@@ -5,7 +5,7 @@ use warnings;
 use v5.10;
 
 # ABSTRACT: Template Renderer Plugin for Mojolicious
-our $VERSION = '1.53'; # VERSION
+our $VERSION = '1.55'; # VERSION
 
 use base 'Mojolicious::Plugin';
 
@@ -38,7 +38,7 @@ Mojolicious::Plugin::TtRenderer - Template Renderer Plugin for Mojolicious
 
 =head1 VERSION
 
-version 1.53
+version 1.55
 
 =head1 SYNOPSIS
 
@@ -235,11 +235,11 @@ L<http://mojolicious.org>.
 
 =head1 AUTHOR
 
-original author: Ask Bjørn Hansen
+Original author: Ask Bjørn Hansen
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 vti
 
@@ -273,7 +273,7 @@ uwisser
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ask Bjørn Hansen.
+This software is copyright (c) 2015 by Ask Bjørn Hansen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
